__title__ = "goodvirus"
__version__ = "1.2.3"
__author__ = "Nico"
__license__ = "MIT"
__description__ = "An ethical, self-updating system watchdog daemon with full-system scanning."
__email__ = "goodvirus.project@proton.me"
